# coding: utf-8

"""
    Aspose.Storage for Cloud API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class AccessTokenResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'access_token': 'str',
        'token_type': 'str',
        'expires_in': 'str',
        'refresh_token': 'str',
        'client_id': 'str',
        'client_refresh_token_life_time_in_minutes': 'str',
        'issued': 'str',
        'expires': 'str'
    }

    attribute_map = {
        'access_token': 'access_token',
        'token_type': 'token_type',
        'expires_in': 'expires_in',
        'refresh_token': 'refresh_token',
        'client_id': 'client_id',
        'client_refresh_token_life_time_in_minutes': 'clientRefreshTokenLifeTimeInMinutes',
        'issued': '.issued',
        'expires': '.expires'
    }

    def __init__(self, access_token=None, token_type=None, expires_in=None, refresh_token=None, client_id=None, client_refresh_token_life_time_in_minutes=None, issued=None, expires=None):
        """
        AccessTokenResponse - a model defined in Swagger
        """

        self._access_token = None
        self._token_type = None
        self._expires_in = None
        self._refresh_token = None
        self._client_id = None
        self._client_refresh_token_life_time_in_minutes = None
        self._issued = None
        self._expires = None
        self.discriminator = None

        self.access_token = access_token
        self.token_type = token_type
        self.expires_in = expires_in
        self.refresh_token = refresh_token
        self.client_id = client_id
        self.client_refresh_token_life_time_in_minutes = client_refresh_token_life_time_in_minutes
        self.issued = issued
        self.expires = expires

    @property
    def access_token(self):
        """
        Gets the access_token of this AccessTokenResponse.

        :return: The access_token of this AccessTokenResponse.
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """
        Sets the access_token of this AccessTokenResponse.

        :param access_token: The access_token of this AccessTokenResponse.
        :type: str
        """
        if access_token is None:
            raise ValueError("Invalid value for `access_token`, must not be `None`")

        self._access_token = access_token

    @property
    def token_type(self):
        """
        Gets the token_type of this AccessTokenResponse.

        :return: The token_type of this AccessTokenResponse.
        :rtype: str
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """
        Sets the token_type of this AccessTokenResponse.

        :param token_type: The token_type of this AccessTokenResponse.
        :type: str
        """
        if token_type is None:
            raise ValueError("Invalid value for `token_type`, must not be `None`")

        self._token_type = token_type

    @property
    def expires_in(self):
        """
        Gets the expires_in of this AccessTokenResponse.

        :return: The expires_in of this AccessTokenResponse.
        :rtype: str
        """
        return self._expires_in

    @expires_in.setter
    def expires_in(self, expires_in):
        """
        Sets the expires_in of this AccessTokenResponse.

        :param expires_in: The expires_in of this AccessTokenResponse.
        :type: str
        """
        if expires_in is None:
            raise ValueError("Invalid value for `expires_in`, must not be `None`")

        self._expires_in = expires_in

    @property
    def refresh_token(self):
        """
        Gets the refresh_token of this AccessTokenResponse.

        :return: The refresh_token of this AccessTokenResponse.
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """
        Sets the refresh_token of this AccessTokenResponse.

        :param refresh_token: The refresh_token of this AccessTokenResponse.
        :type: str
        """
        if refresh_token is None:
            raise ValueError("Invalid value for `refresh_token`, must not be `None`")

        self._refresh_token = refresh_token

    @property
    def client_id(self):
        """
        Gets the client_id of this AccessTokenResponse.

        :return: The client_id of this AccessTokenResponse.
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """
        Sets the client_id of this AccessTokenResponse.

        :param client_id: The client_id of this AccessTokenResponse.
        :type: str
        """
        if client_id is None:
            raise ValueError("Invalid value for `client_id`, must not be `None`")

        self._client_id = client_id

    @property
    def client_refresh_token_life_time_in_minutes(self):
        """
        Gets the client_refresh_token_life_time_in_minutes of this AccessTokenResponse.

        :return: The client_refresh_token_life_time_in_minutes of this AccessTokenResponse.
        :rtype: str
        """
        return self._client_refresh_token_life_time_in_minutes

    @client_refresh_token_life_time_in_minutes.setter
    def client_refresh_token_life_time_in_minutes(self, client_refresh_token_life_time_in_minutes):
        """
        Sets the client_refresh_token_life_time_in_minutes of this AccessTokenResponse.

        :param client_refresh_token_life_time_in_minutes: The client_refresh_token_life_time_in_minutes of this AccessTokenResponse.
        :type: str
        """
        if client_refresh_token_life_time_in_minutes is None:
            raise ValueError("Invalid value for `client_refresh_token_life_time_in_minutes`, must not be `None`")

        self._client_refresh_token_life_time_in_minutes = client_refresh_token_life_time_in_minutes

    @property
    def issued(self):
        """
        Gets the issued of this AccessTokenResponse.

        :return: The issued of this AccessTokenResponse.
        :rtype: str
        """
        return self._issued

    @issued.setter
    def issued(self, issued):
        """
        Sets the issued of this AccessTokenResponse.

        :param issued: The issued of this AccessTokenResponse.
        :type: str
        """
        if issued is None:
            raise ValueError("Invalid value for `issued`, must not be `None`")

        self._issued = issued

    @property
    def expires(self):
        """
        Gets the expires of this AccessTokenResponse.

        :return: The expires of this AccessTokenResponse.
        :rtype: str
        """
        return self._expires

    @expires.setter
    def expires(self, expires):
        """
        Sets the expires of this AccessTokenResponse.

        :param expires: The expires of this AccessTokenResponse.
        :type: str
        """
        if expires is None:
            raise ValueError("Invalid value for `expires`, must not be `None`")

        self._expires = expires

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, AccessTokenResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.Storage for Cloud API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class FileResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'is_folder': 'bool',
        'modified_date': 'str',
        'size': 'int',
        'path': 'str',
        'is_directory': 'bool'
    }

    attribute_map = {
        'name': 'Name',
        'is_folder': 'IsFolder',
        'modified_date': 'ModifiedDate',
        'size': 'Size',
        'path': 'Path',
        'is_directory': 'IsDirectory'
    }

    discriminator_value_class_map = {
        '': 'FileVersion'
    }

    def __init__(self, name=None, is_folder=None, modified_date=None, size=None, path=None, is_directory=None):
        """
        FileResponse - a model defined in Swagger
        """

        self._name = None
        self._is_folder = None
        self._modified_date = None
        self._size = None
        self._path = None
        self._is_directory = None
        self.discriminator = 'Type'

        if name is not None:
          self.name = name
        self.is_folder = is_folder
        self.modified_date = modified_date
        self.size = size
        if path is not None:
          self.path = path
        self.is_directory = is_directory

    @property
    def name(self):
        """
        Gets the name of this FileResponse.

        :return: The name of this FileResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FileResponse.

        :param name: The name of this FileResponse.
        :type: str
        """

        self._name = name

    @property
    def is_folder(self):
        """
        Gets the is_folder of this FileResponse.

        :return: The is_folder of this FileResponse.
        :rtype: bool
        """
        return self._is_folder

    @is_folder.setter
    def is_folder(self, is_folder):
        """
        Sets the is_folder of this FileResponse.

        :param is_folder: The is_folder of this FileResponse.
        :type: bool
        """
        if is_folder is None:
            raise ValueError("Invalid value for `is_folder`, must not be `None`")

        self._is_folder = is_folder

    @property
    def modified_date(self):
        """
        Gets the modified_date of this FileResponse.

        :return: The modified_date of this FileResponse.
        :rtype: str
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this FileResponse.

        :param modified_date: The modified_date of this FileResponse.
        :type: str
        """
        if modified_date is None:
            raise ValueError("Invalid value for `modified_date`, must not be `None`")

        self._modified_date = modified_date

    @property
    def size(self):
        """
        Gets the size of this FileResponse.

        :return: The size of this FileResponse.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this FileResponse.

        :param size: The size of this FileResponse.
        :type: int
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")

        self._size = size

    @property
    def path(self):
        """
        Gets the path of this FileResponse.

        :return: The path of this FileResponse.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this FileResponse.

        :param path: The path of this FileResponse.
        :type: str
        """

        self._path = path

    @property
    def is_directory(self):
        """
        Gets the is_directory of this FileResponse.

        :return: The is_directory of this FileResponse.
        :rtype: bool
        """
        return self._is_directory

    @is_directory.setter
    def is_directory(self, is_directory):
        """
        Sets the is_directory of this FileResponse.

        :param is_directory: The is_directory of this FileResponse.
        :type: bool
        """
        if is_directory is None:
            raise ValueError("Invalid value for `is_directory`, must not be `None`")

        self._is_directory = is_directory

    def get_real_child_model(self, data):
        """
        Returns the real base class specified by the discriminator
        """
        discriminator_value = data[self.discriminator].lower()
        if self.discriminator_value_class_map.has_key(discriminator_value):
            return self.discriminator_value_class_map[discriminator_value]
        else:
            return None

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FileResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.Storage for Cloud API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .access_token_response import AccessTokenResponse
from .aspose_response import AsposeResponse
from .disc_usage import DiscUsage
from .file_exist import FileExist
from .file_response import FileResponse
from .copy_file_response import CopyFileResponse
from .create_folder_response import CreateFolderResponse
from .disc_usage_response import DiscUsageResponse
from .file_exist_response import FileExistResponse
from .file_version import FileVersion
from .file_versions_response import FileVersionsResponse
from .files_response import FilesResponse
from .move_file_response import MoveFileResponse
from .move_folder_response import MoveFolderResponse
from .remove_file_response import RemoveFileResponse
from .remove_folder_response import RemoveFolderResponse
from .storage_exist_response import StorageExistResponse
from .upload_response import UploadResponse



# coding: utf-8

"""
    Aspose.Storage for Cloud API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class AsposeResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'code': 'int',
        'status': 'str'
    }

    attribute_map = {
        'code': 'Code',
        'status': 'Status'
    }

    discriminator_value_class_map = {
        '': 'CopyFileResponse',
        '': 'StorageExistResponse',
        '': 'FilesResponse',
        '': 'FileVersionsResponse',
        '': 'UploadResponse',
        '': 'DiscUsageResponse',
        '': 'FileExistResponse',
        '': 'RemoveFolderResponse',
        '': 'MoveFileResponse',
        '': 'MoveFolderResponse',
        '': 'RemoveFileResponse',
        '': 'CreateFolderResponse'
    }

    def __init__(self, code=None, status=None):
        """
        AsposeResponse - a model defined in Swagger
        """

        self._code = None
        self._status = None
        self.discriminator = 'Type'

        self.code = code
        if status is not None:
          self.status = status

    @property
    def code(self):
        """
        Gets the code of this AsposeResponse.

        :return: The code of this AsposeResponse.
        :rtype: int
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this AsposeResponse.

        :param code: The code of this AsposeResponse.
        :type: int
        """
        if code is None:
            raise ValueError("Invalid value for `code`, must not be `None`")

        self._code = code

    @property
    def status(self):
        """
        Gets the status of this AsposeResponse.

        :return: The status of this AsposeResponse.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this AsposeResponse.

        :param status: The status of this AsposeResponse.
        :type: str
        """

        self._status = status

    def get_real_child_model(self, data):
        """
        Returns the real base class specified by the discriminator
        """
        discriminator_value = data[self.discriminator].lower()
        if self.discriminator_value_class_map.has_key(discriminator_value):
            return self.discriminator_value_class_map[discriminator_value]
        else:
            return None

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, AsposeResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.Storage for Cloud API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class DiscUsage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'used_size': 'int',
        'total_size': 'int'
    }

    attribute_map = {
        'used_size': 'UsedSize',
        'total_size': 'TotalSize'
    }

    def __init__(self, used_size=None, total_size=None):
        """
        DiscUsage - a model defined in Swagger
        """

        self._used_size = None
        self._total_size = None
        self.discriminator = None

        self.used_size = used_size
        self.total_size = total_size

    @property
    def used_size(self):
        """
        Gets the used_size of this DiscUsage.

        :return: The used_size of this DiscUsage.
        :rtype: int
        """
        return self._used_size

    @used_size.setter
    def used_size(self, used_size):
        """
        Sets the used_size of this DiscUsage.

        :param used_size: The used_size of this DiscUsage.
        :type: int
        """
        if used_size is None:
            raise ValueError("Invalid value for `used_size`, must not be `None`")

        self._used_size = used_size

    @property
    def total_size(self):
        """
        Gets the total_size of this DiscUsage.

        :return: The total_size of this DiscUsage.
        :rtype: int
        """
        return self._total_size

    @total_size.setter
    def total_size(self, total_size):
        """
        Sets the total_size of this DiscUsage.

        :param total_size: The total_size of this DiscUsage.
        :type: int
        """
        if total_size is None:
            raise ValueError("Invalid value for `total_size`, must not be `None`")

        self._total_size = total_size

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DiscUsage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.Storage for Cloud API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.access_token_response import AccessTokenResponse
from .models.aspose_response import AsposeResponse
from .models.disc_usage import DiscUsage
from .models.file_exist import FileExist
from .models.file_response import FileResponse
from .models.copy_file_response import CopyFileResponse
from .models.create_folder_response import CreateFolderResponse
from .models.disc_usage_response import DiscUsageResponse
from .models.file_exist_response import FileExistResponse
from .models.file_version import FileVersion
from .models.file_versions_response import FileVersionsResponse
from .models.files_response import FilesResponse
from .models.move_file_response import MoveFileResponse
from .models.move_folder_response import MoveFolderResponse
from .models.remove_file_response import RemoveFileResponse
from .models.remove_folder_response import RemoveFolderResponse
from .models.storage_exist_response import StorageExistResponse
from .models.upload_response import UploadResponse

# import apis into sdk package
from .apis.storage_api import StorageApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration



# coding: utf-8

"""
    Aspose.Storage for Cloud API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import asposestoragecloud
from asposestoragecloud.rest import ApiException
from asposestoragecloud.apis.storage_api import StorageApi
from asposestoragecloud.api_client import ApiClient

class TestStorageApi(unittest.TestCase):
    """ StorageApi unit test stubs """

    def setUp(self):
        ABSPATH = os.path.abspath(os.path.realpath(os.path.dirname(__file__)) + "/..")
        self.dataFolder = os.path.join(ABSPATH, "Data")
        
        self.apiClient = ApiClient(apiKey='xxxx', appSid='xxxx-xxxx-xxxx-xxxxxx')
        self.api = asposestoragecloud.apis.storage_api.StorageApi(self.apiClient)

    def tearDown(self):
        pass

    # File APIs Test Cases
    def test_put_create(self):
        """
        Test case for put_create

        Upload a specific file 
        """
        fileName = "Aspose_test.png" #"testfile.txt"
        filePath = os.path.join(self.dataFolder, fileName)
        with open(filePath, 'rb') as fp:
            fileData = fp.read()
        response = self.api.put_create(fileName, fileData)
        self.assertTrue(response)

    def test_get_download(self):
        """
        Test case for get_download
        
        Download a specific file
        """
        fileName = 'testfile.txt'
        response = self.api.get_download(fileName)
        self.assertTrue(response)

    def test_post_move_file(self):
        """
        Test case for post_move_file
        
        Move a specific file
        """
        src =  "testfile.txt"
        dest = os.path.join("Documents", "testfile.txt")
        response = self.api.post_move_file(src, dest)
        self.assertTrue(response)

    def test_delete_file(self):
        """
        Test case for delete_file
        
        Remove a specific file
        """
        fileName = 'testfile.txt'
        response = self.api.delete_file(fileName)
        self.assertTrue(response['Code'] == 200)


    # Folder APIs Test Cases
    def test_get_list_files(self):
        """
        Test case for get_list_files
        
        Get the file listing of a specific folder
        """
        response = self.api.get_list_files()
        self.assertTrue(response)

    def test_put_create_folder(self):
        """
        Test case for put_create_folder

        Create the folder 
        """
        folderName = "My Documents"
        response = self.api.put_create_folder(folderName)
        self.assertTrue(response)

    def test_post_move_folder(self):
        """
        Test case for post_move_folder
        
        Move a specific folder
        """
        srcFolder = "moveFrom"
        destFolder = "moveTo"
            
        response = self.api.post_move_folder(srcFolder, destFolder)
        self.assertTrue(response)

    def test_delete_folder(self):
        """
        Test case for delete_folder
        
        Remove a specific folder
        """
        folderName = 'Pictures'
        response = self.api.delete_folder(folderName)
        self.assertTrue(response['Code'] == 200)

    def test_put_copy(self):
        """
        Test case for put_copy
        
        Copy a specific file
        """
        path = "testfile.txt"
        newdest = os.path.join("My Documents", "testfile.txt")
        response = self.api.put_copy(path, newdest)
        self.assertTrue(response)

    def test_put_copy_folder(self):
        """
        Test case for put_copy_folder
        
        Copy a folder
        """
        path = "Word Documents"
        newdest = os.path.join("My Documents", "Word Documents")
        response = self.api.put_copy_folder(path, newdest)
        self.assertTrue(response)

    # Storage APIs Test Cases
    def test_get_is_storage_exist(self):
        """
        Test case for get_is_storage_exist
        
        Check if storage exists
        """
        storageName = "MyDropboxStorage"
        response = self.api.get_is_storage_exist(storageName)
        self.assertTrue(response)

    def test_get_is_exist(self):
        """
        Test case for get_is_exist
        
        Check if a specific file or folder exists
        """
        response = self.api.get_is_exist('testfile.txt')
        self.assertTrue(response.file_exist.is_exist)

    def test_get_disc_usage(self):
        """
        Test case for get_disc_usage
        
        Check the disk usage of the current account
        """
        response = self.api.get_disc_usage()
        self.assertTrue(response)

    def test_get_list_file_versions(self):
        """
        Test case for get_list_file_versions
        
        Get the file's versions list
        """
        fileName = 'testfile.txt'
        response = self.api.get_list_file_versions(fileName)
        self.assertTrue(response)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aspose.Storage for Cloud API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import sys
from setuptools import setup, find_packages

NAME = "asposestoragecloud"
VERSION = "1.0.4"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil", "chardet"]

setup(
    name=NAME,
    version=VERSION,
    description="Aspose.Storage for Cloud APIs",
    author_email="aspose.cloud@asposeptyltd.com",
    license='MIT',
    url="https://www.aspose.cloud/",
    keywords=["Aspose.Storage for Cloud APIs"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    Aspose.Storage for Cloud APIs https://apireference.aspose.cloud/storage/
    """
)



# coding: utf-8

"""
    Aspose.Storage for Cloud API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..api_client import ApiClient


class StorageApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_file(self, path, **kwargs):
        """
        Remove a specific file 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_file(path, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Path of the file including file name and extension e.g. /Folder1/file.ext (required)
        :param str version_id: File's version
        :param str storage: User's storage name
        :return: RemoveFileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.delete_file_with_http_info(path, **kwargs)
        else:
            (data) = self.delete_file_with_http_info(path, **kwargs)
            return data

    def delete_file_with_http_info(self, path, **kwargs):
        """
        Remove a specific file 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_file_with_http_info(path, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Path of the file including file name and extension e.g. /Folder1/file.ext (required)
        :param str version_id: File's version
        :param str storage: User's storage name
        :return: RemoveFileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['path', 'version_id', 'storage']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if ('path' not in params) or (params['path'] is None):
            raise ValueError("Missing the required parameter `path` when calling `delete_file`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'path' in params:
            query_params.append(('path', params['path']))
        if 'version_id' in params:
            query_params.append(('versionId', params['version_id']))
        if 'storage' in params:
            query_params.append(('storage', params['storage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/file', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RemoveFileResponse',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def delete_folder(self, path, **kwargs):
        """
        Remove a specific folder 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_folder(path, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Folder path e.g. /Folder1 (required)
        :param str storage: User's storage name
        :param bool recursive: Remove recursivelly inner folder/files. If false and folder contains data than exception is raised.
        :return: RemoveFolderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.delete_folder_with_http_info(path, **kwargs)
        else:
            (data) = self.delete_folder_with_http_info(path, **kwargs)
            return data

    def delete_folder_with_http_info(self, path, **kwargs):
        """
        Remove a specific folder 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.delete_folder_with_http_info(path, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Folder path e.g. /Folder1 (required)
        :param str storage: User's storage name
        :param bool recursive: Remove recursivelly inner folder/files. If false and folder contains data than exception is raised.
        :return: RemoveFolderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['path', 'storage', 'recursive']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_folder" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if ('path' not in params) or (params['path'] is None):
            raise ValueError("Missing the required parameter `path` when calling `delete_folder`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'path' in params:
            query_params.append(('path', params['path']))
        if 'storage' in params:
            query_params.append(('storage', params['storage']))
        if 'recursive' in params:
            query_params.append(('recursive', params['recursive']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/folder', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='RemoveFolderResponse',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_disc_usage(self, **kwargs):
        """
        Check the disk usage of the current account 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_disc_usage(async=True)
        >>> result = thread.get()

        :param async bool
        :param str storage: User's storage name
        :return: DiscUsageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_disc_usage_with_http_info(**kwargs)
        else:
            (data) = self.get_disc_usage_with_http_info(**kwargs)
            return data

    def get_disc_usage_with_http_info(self, **kwargs):
        """
        Check the disk usage of the current account 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_disc_usage_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str storage: User's storage name
        :return: DiscUsageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['storage']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_disc_usage" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'storage' in params:
            query_params.append(('storage', params['storage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/disc', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='DiscUsageResponse',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_download(self, path, **kwargs):
        """
        Download a specific file 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_download(path, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Path of the file including the file name and extension e.g. /file.ext (required)
        :param str version_id: File's version
        :param str storage: User's storage name
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_download_with_http_info(path, **kwargs)
        else:
            (data) = self.get_download_with_http_info(path, **kwargs)
            return data

    def get_download_with_http_info(self, path, **kwargs):
        """
        Download a specific file 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_download_with_http_info(path, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Path of the file including the file name and extension e.g. /file.ext (required)
        :param str version_id: File's version
        :param str storage: User's storage name
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['path', 'version_id', 'storage']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_download" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if ('path' not in params) or (params['path'] is None):
            raise ValueError("Missing the required parameter `path` when calling `get_download`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'path' in params:
            query_params.append(('path', params['path']))
        if 'version_id' in params:
            query_params.append(('versionId', params['version_id']))
        if 'storage' in params:
            query_params.append(('storage', params['storage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['multipart/form-data'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/file', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='file',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_is_exist(self, path, **kwargs):
        """
        Check if a specific file or folder exists
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_is_exist(path, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: File or folder path e.g. /file.ext or /Folder1 (required)
        :param str version_id: File's version
        :param str storage: User's storage name
        :return: FileExistResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_is_exist_with_http_info(path, **kwargs)
        else:
            (data) = self.get_is_exist_with_http_info(path, **kwargs)
            return data

    def get_is_exist_with_http_info(self, path, **kwargs):
        """
        Check if a specific file or folder exists
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_is_exist_with_http_info(path, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: File or folder path e.g. /file.ext or /Folder1 (required)
        :param str version_id: File's version
        :param str storage: User's storage name
        :return: FileExistResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['path', 'version_id', 'storage']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_is_exist" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if ('path' not in params) or (params['path'] is None):
            raise ValueError("Missing the required parameter `path` when calling `get_is_exist`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'path' in params:
            query_params.append(('path', params['path']))
        if 'version_id' in params:
            query_params.append(('versionId', params['version_id']))
        if 'storage' in params:
            query_params.append(('storage', params['storage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/exist', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FileExistResponse',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_is_storage_exist(self, name, **kwargs):
        """
        Check if storage exists 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_is_storage_exist(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: Storage name (required)
        :return: StorageExistResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_is_storage_exist_with_http_info(name, **kwargs)
        else:
            (data) = self.get_is_storage_exist_with_http_info(name, **kwargs)
            return data

    def get_is_storage_exist_with_http_info(self, name, **kwargs):
        """
        Check if storage exists 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_is_storage_exist_with_http_info(name, async=True)
        >>> result = thread.get()

        :param async bool
        :param str name: Storage name (required)
        :return: StorageExistResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_is_storage_exist" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params) or (params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `get_is_storage_exist`")


        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['name'] = params['name']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/{name}/exist', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='StorageExistResponse',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_list_file_versions(self, path, **kwargs):
        """
        Get the file's versions list 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_list_file_versions(path, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: File path e.g. /file.ext or /Folder1/file.ext (required)
        :param str storage: User's storage name
        :return: FileVersionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_list_file_versions_with_http_info(path, **kwargs)
        else:
            (data) = self.get_list_file_versions_with_http_info(path, **kwargs)
            return data

    def get_list_file_versions_with_http_info(self, path, **kwargs):
        """
        Get the file's versions list 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_list_file_versions_with_http_info(path, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: File path e.g. /file.ext or /Folder1/file.ext (required)
        :param str storage: User's storage name
        :return: FileVersionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['path', 'storage']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_list_file_versions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if ('path' not in params) or (params['path'] is None):
            raise ValueError("Missing the required parameter `path` when calling `get_list_file_versions`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'path' in params:
            query_params.append(('path', params['path']))
        if 'storage' in params:
            query_params.append(('storage', params['storage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/version', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FileVersionsResponse',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_list_files(self, **kwargs):
        """
        Get the file listing of a specific folder 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_list_files(async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Start with name of storage e.g. root folder '/'or some folder '/folder1/..'
        :param str storage: User's storage name
        :return: FilesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_list_files_with_http_info(**kwargs)
        else:
            (data) = self.get_list_files_with_http_info(**kwargs)
            return data

    def get_list_files_with_http_info(self, **kwargs):
        """
        Get the file listing of a specific folder 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_list_files_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Start with name of storage e.g. root folder '/'or some folder '/folder1/..'
        :param str storage: User's storage name
        :return: FilesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['path', 'storage']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_list_files" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'path' in params:
            query_params.append(('path', params['path']))
        if 'storage' in params:
            query_params.append(('storage', params['storage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/folder', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FilesResponse',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def post_move_file(self, src, dest, **kwargs):
        """
        Move a specific file 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.post_move_file(src, dest, async=True)
        >>> result = thread.get()

        :param async bool
        :param str src: Source file path e.g. /fileSource.ext (required)
        :param str dest: Destination file path e.g. /fileDestination.ext (required)
        :param str version_id: Source file's version,
        :param str storage: User's source storage name
        :param str dest_storage: User's destination storage name
        :return: MoveFileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.post_move_file_with_http_info(src, dest, **kwargs)
        else:
            (data) = self.post_move_file_with_http_info(src, dest, **kwargs)
            return data

    def post_move_file_with_http_info(self, src, dest, **kwargs):
        """
        Move a specific file 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.post_move_file_with_http_info(src, dest, async=True)
        >>> result = thread.get()

        :param async bool
        :param str src: Source file path e.g. /fileSource.ext (required)
        :param str dest: Destination file path e.g. /fileDestination.ext (required)
        :param str version_id: Source file's version,
        :param str storage: User's source storage name
        :param str dest_storage: User's destination storage name
        :return: MoveFileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['src', 'dest', 'version_id', 'storage', 'dest_storage']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_move_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'src' is set
        if ('src' not in params) or (params['src'] is None):
            raise ValueError("Missing the required parameter `src` when calling `post_move_file`")
        # verify the required parameter 'dest' is set
        if ('dest' not in params) or (params['dest'] is None):
            raise ValueError("Missing the required parameter `dest` when calling `post_move_file`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'src' in params:
            query_params.append(('src', params['src']))
        if 'dest' in params:
            query_params.append(('dest', params['dest']))
        if 'version_id' in params:
            query_params.append(('versionId', params['version_id']))
        if 'storage' in params:
            query_params.append(('storage', params['storage']))
        if 'dest_storage' in params:
            query_params.append(('destStorage', params['dest_storage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['multipart/form-data'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/file', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='MoveFileResponse',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def post_move_folder(self, src, dest, **kwargs):
        """
        Move a specific folder 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.post_move_folder(src, dest, async=True)
        >>> result = thread.get()

        :param async bool
        :param str src: Source folder path e.g. /Folder1 (required)
        :param str dest: Destination folder path e.g. /Folder2 (required)
        :param str storage: User's source storage name
        :param str dest_storage: User's destination storage name
        :return: MoveFolderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.post_move_folder_with_http_info(src, dest, **kwargs)
        else:
            (data) = self.post_move_folder_with_http_info(src, dest, **kwargs)
            return data

    def post_move_folder_with_http_info(self, src, dest, **kwargs):
        """
        Move a specific folder 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.post_move_folder_with_http_info(src, dest, async=True)
        >>> result = thread.get()

        :param async bool
        :param str src: Source folder path e.g. /Folder1 (required)
        :param str dest: Destination folder path e.g. /Folder2 (required)
        :param str storage: User's source storage name
        :param str dest_storage: User's destination storage name
        :return: MoveFolderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['src', 'dest', 'storage', 'dest_storage']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_move_folder" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'src' is set
        if ('src' not in params) or (params['src'] is None):
            raise ValueError("Missing the required parameter `src` when calling `post_move_folder`")
        # verify the required parameter 'dest' is set
        if ('dest' not in params) or (params['dest'] is None):
            raise ValueError("Missing the required parameter `dest` when calling `post_move_folder`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'src' in params:
            query_params.append(('src', params['src']))
        if 'dest' in params:
            query_params.append(('dest', params['dest']))
        if 'storage' in params:
            query_params.append(('storage', params['storage']))
        if 'dest_storage' in params:
            query_params.append(('destStorage', params['dest_storage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/folder', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='MoveFolderResponse',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def put_create(self, path, file, **kwargs):
        """
        Upload a specific file 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.put_create(path, file, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Path where to upload including filename and extension e.g. /file.ext or /Folder 1/file.ext (required)
        :param file file: File to upload (required)
        :param str version_id: Source file's version
        :param str storage: User's storage name
        :return: UploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.put_create_with_http_info(path, file, **kwargs)
        else:
            (data) = self.put_create_with_http_info(path, file, **kwargs)
            return data

    def put_create_with_http_info(self, path, fileData, **kwargs):
        """
        Upload a specific file 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.put_create_with_http_info(path, fileData, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Path where to upload including filename and extension e.g. /file.ext or /Folder 1/file.ext (required)
        :param IOBase fileData: File Data to upload (required)
        :param str version_id: Source file's version
        :param str storage: User's storage name
        :return: UploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['path', 'fileData', 'version_id', 'storage']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if ('path' not in params) or (params['path'] is None):
            raise ValueError("Missing the required parameter `path` when calling `put_create`")
        # verify the required parameter 'fileData' is set
        if ('fileData' not in params) or (params['fileData'] is None):
            raise ValueError("Missing the required parameter `fileData` when calling `put_create`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'path' in params:
            query_params.append(('path', params['path']))
        if 'version_id' in params:
            query_params.append(('versionId', params['version_id']))
        if 'storage' in params:
            query_params.append(('storage', params['storage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = fileData
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['multipart/form-data'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/file', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='UploadResponse',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def put_create_folder(self, path, **kwargs):
        """
        Create the folder 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.put_create_folder(path, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Target folder's path e.g. Folder1/Folder2/. The folders will be created recursively (required)
        :param str storage: User's source storage name
        :param str dest_storage: User's destination storage name
        :return: CreateFolderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.put_create_folder_with_http_info(path, **kwargs)
        else:
            (data) = self.put_create_folder_with_http_info(path, **kwargs)
            return data

    def put_create_folder_with_http_info(self, path, **kwargs):
        """
        Create the folder 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.put_create_folder_with_http_info(path, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Target folder's path e.g. Folder1/Folder2/. The folders will be created recursively (required)
        :param str storage: User's source storage name
        :param str dest_storage: User's destination storage name
        :return: CreateFolderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['path', 'storage', 'dest_storage']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_create_folder" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if ('path' not in params) or (params['path'] is None):
            raise ValueError("Missing the required parameter `path` when calling `put_create_folder`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'path' in params:
            query_params.append(('path', params['path']))
        if 'storage' in params:
            query_params.append(('storage', params['storage']))
        if 'dest_storage' in params:
            query_params.append(('destStorage', params['dest_storage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/folder', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CreateFolderResponse',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def put_copy(self, path, newdest, **kwargs):
        """
        Copy a specific file 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.put_copy(path, newdest, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Source file's path. Sample: '/Folder 1/file.ext' or '/Bucket/Folder 1/file.ext' (required)
        :param str newdest: Destination file path (required)
        :param str version_id: Source file's version
        :param str storage: User's source storage name
        :param str dest_storage: User's destination storage name
        :return: CopyFileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.put_copy_with_http_info(path, newdest, **kwargs)
        else:
            (data) = self.put_copy_with_http_info(path, newdest, **kwargs)
            return data

    def put_copy_with_http_info(self, path, newdest, **kwargs):
        """
        Copy a specific file 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.put_copy_with_http_info(path, newdest, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Source file's path. Sample: '/Folder 1/file.ext' or '/Bucket/Folder 1/file.ext' (required)
        :param str newdest: Destination file path (required)
        :param str version_id: Source file's version
        :param str storage: User's source storage name
        :param str dest_storage: User's destination storage name
        :return: CopyFileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['path', 'newdest', 'version_id', 'storage', 'dest_storage']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_copy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if ('path' not in params) or (params['path'] is None):
            raise ValueError("Missing the required parameter `path` when calling `put_copy`")
        # verify the required parameter 'newdest' is set
        if ('newdest' not in params) or (params['newdest'] is None):
            raise ValueError("Missing the required parameter `newdest` when calling `put_copy`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'path' in params:
            query_params.append(('path', params['path']))
        if 'newdest' in params:
            query_params.append(('newdest', params['newdest']))
        if 'version_id' in params:
            query_params.append(('versionId', params['version_id']))
        if 'storage' in params:
            query_params.append(('storage', params['storage']))
        if 'dest_storage' in params:
            query_params.append(('destStorage', params['dest_storage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['multipart/form-data'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/file', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CopyFileResponse',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def put_copy_folder(self, path, newdest, **kwargs):
        """
        Copy a folder 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.put_copy_folder(path, newdest, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Source folder path e.g. /Folder1 (required)
        :param str newdest: Destination folder path e.g. /Folder2 (required)
        :param str storage: User's source storage name
        :param str dest_storage: User's destination storage name
        :return: CreateFolderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.put_copy_folder_with_http_info(path, newdest, **kwargs)
        else:
            (data) = self.put_copy_folder_with_http_info(path, newdest, **kwargs)
            return data

    def put_copy_folder_with_http_info(self, path, newdest, **kwargs):
        """
        Copy a folder 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.put_copy_folder_with_http_info(path, newdest, async=True)
        >>> result = thread.get()

        :param async bool
        :param str path: Source folder path e.g. /Folder1 (required)
        :param str newdest: Destination folder path e.g. /Folder2 (required)
        :param str storage: User's source storage name
        :param str dest_storage: User's destination storage name
        :return: CreateFolderResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['path', 'newdest', 'storage', 'dest_storage']
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_copy_folder" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'path' is set
        if ('path' not in params) or (params['path'] is None):
            raise ValueError("Missing the required parameter `path` when calling `put_copy_folder`")
        # verify the required parameter 'newdest' is set
        if ('newdest' not in params) or (params['newdest'] is None):
            raise ValueError("Missing the required parameter `newdest` when calling `put_copy_folder`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'path' in params:
            query_params.append(('path', params['path']))
        if 'newdest' in params:
            query_params.append(('newdest', params['newdest']))
        if 'storage' in params:
            query_params.append(('storage', params['storage']))
        if 'dest_storage' in params:
            query_params.append(('destStorage', params['dest_storage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api('/storage/folder', 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CreateFolderResponse',
                                        auth_settings=auth_settings,
                                        async=params.get('async'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)
